@@ -14,10 +14,10 @@ import sqlalchemy as sa
 from alembic import op
 
 # revision identifiers, used by Alembic.
-revision = '41157f1933d6'
-down_revision = 'c25ef2c50ffa'
+revision = "41157f1933d6"
+down_revision = "c25ef2c50ffa"
 branch_labels = ()
-depends_on = 'eb9743315a9d'  # invenio-accounts: add_userprofile
+depends_on = "eb9743315a9d"  # invenio-accounts: add_userprofile
 
 
 def upgrade():
@@ -34,10 +34,7 @@ def upgrade():
         profile_data = {
             "full_name": full_name,
         }
-        preferences = {
-            "visibility": "restricted",
-            "email_visibility": "restricted"
-        }
+        preferences = {"visibility": "restricted", "email_visibility": "restricted"}
 
         query = (
             "UPDATE accounts_user SET "
@@ -55,29 +52,28 @@ def upgrade():
         )
         op.execute(query)
 
-    op.drop_table('userprofiles_userprofile')
+    op.drop_table("userprofiles_userprofile")
 
 
 def downgrade():
     """Downgrade database."""
     op.create_table(
-        'userprofiles_userprofile',
+        "userprofiles_userprofile",
+        sa.Column("user_id", sa.INTEGER(), autoincrement=False, nullable=False),
         sa.Column(
-            'user_id', sa.INTEGER(), autoincrement=False, nullable=False),
+            "username", sa.VARCHAR(length=255), autoincrement=False, nullable=True
+        ),
         sa.Column(
-            'username', sa.VARCHAR(length=255), autoincrement=False,
-            nullable=True),
+            "displayname", sa.VARCHAR(length=255), autoincrement=False, nullable=True
+        ),
         sa.Column(
-            'displayname', sa.VARCHAR(length=255), autoincrement=False,
-            nullable=True),
-        sa.Column(
-            'full_name', sa.VARCHAR(length=255), autoincrement=False,
-            nullable=False),
+            "full_name", sa.VARCHAR(length=255), autoincrement=False, nullable=False
+        ),
         sa.ForeignKeyConstraint(
-            ['user_id'], ['accounts_user.id'],
-            name='fk_userprofiles_userprofile_user_id_accounts_user'),
-        sa.PrimaryKeyConstraint('user_id', name='pk_userprofiles_userprofile'),
-        sa.UniqueConstraint(
-            'username',
-            name='uq_userprofiles_userprofile_username')
+            ["user_id"],
+            ["accounts_user.id"],
+            name="fk_userprofiles_userprofile_user_id_accounts_user",
+        ),
+        sa.PrimaryKeyConstraint("user_id", name="pk_userprofiles_userprofile"),
+        sa.UniqueConstraint("username", name="uq_userprofiles_userprofile_username"),
     )
