@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2015-2022 CERN.
+# Copyright (C) 2021      TU Wien.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """API for user profiles."""
 
-from __future__ import absolute_import, print_function
+from warnings import warn
 
-from flask import g
 from flask_security import current_user
 from werkzeug.local import LocalProxy
 
-from .models import AnonymousUserProfile, UserProfile
+from .models import UserProfileProxy
 
 
 def _get_current_userprofile():
@@ -26,17 +26,11 @@ def _get_current_userprofile():
 
     :returns: The :class:`invenio_userprofiles.models.UserProfile` instance.
     """
-    if current_user.is_anonymous:
-        return AnonymousUserProfile()
-
-    profile = getattr(
-        g, 'userprofile', UserProfile.get_by_userid(current_user.get_id()))
-
-    if profile is None:
-        profile = UserProfile(user_id=int(current_user.get_id()))
-        g.userprofile = profile
-
-    return profile
+    warn(
+        "current_userprofile is deprecated, use current_user instead",
+        DeprecationWarning,
+    )
+    return UserProfileProxy(current_user)
 
 
 current_userprofile = LocalProxy(lambda: _get_current_userprofile())
